/*
   mkvmerge -- utility for splicing together matroska files
   from component media subtypes

   Distributed under the GPL
   see the file COPYING for details
   or visit http://www.gnu.org/copyleft/gpl.html

   terminal access functions

   Written by Moritz Bunkus <moritz@bunkus.org>.
*/

#ifndef __MTX_COMMON_TERMINAL_H
#define __MTX_COMMON_TERMINAL_H

#include "common/os.h"

int get_terminal_columns();

#endif  // __MTX_COMMON_TERMINAL_H
